==> php55-owncloud-8.2.0.tgz: share/owncloud/apps/files_external/l10n/oc.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "L’etapa 1 a fracassat. Error : %s",
    "Step 2 failed. Exception: %s" : "L’etapa 2 a fracassat. Error : %s",
    "External storage" : "Emmagazinatge extèrne",
    "Storage with id \"%i\" not found" : "Emmagazinatge amb l'id \"%i\" pas trobat",
    "Invalid mount point" : "Punt de montatge invalid",
    "Invalid storage backend \"%s\"" : "Servici d'emmagazinatge invalid : \"%s\"",
    "Personal" : "Personal",
    "System" : "Sistèma",
    "Grant access" : "Autorizar l'accès",
    "Access granted" : "Accès autorizat",
    "Generate keys" : "Generar de claus",
    "Error generating key pair" : "Error al moment de la generacion de las claus",
    "Enable encryption" : "Activar lo chiframent",
    "Enable previews" : "Activar las previsualizacions",
    "Never" : "Pas jamai",
    "(group)" : "(grop)",
    "Saved" : "Salvat",
    "Access key" : "Clau d'accès",
    "Secret key" : "Clau secreta",
    "None" : "Pas cap",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "Username" : "Nom d'utilizaire",
    "Password" : "Senhal",
    "API key" : "Clau API",
    "RSA public key" : "Clau publica RSA",
    "Public key" : "Clau publica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l'òste",
    "Port" : "Pòrt",
    "Region" : "Region",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Accès per path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sosdorsièr distant",
    "Secure https://" : "Securizacion https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Òste",
    "Secure ftps://" : "Securizacion ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Emplaçament",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP amb un identificant secret",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partejar",
    "Domain" : "Domeni",
    "SMB / CIFS using OC login" : "SMB / CIFS en utilizant los identificants OC",
    "Username as share" : "Nom d'utilizaire coma nom de partiment",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom del servici",
    "<b>Note:</b> " : "<b>Atencion :</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion :</b> La presa en carga de cURL per PHP es pas activada o installada. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion : </b> La presa en carga del FTP per PHP es pas activada o installada. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion : </b> \"%s\" es pas installat. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "No external storage configured" : "Aucun emmagazinatge externe configurat",
    "You can add external storages in the personal settings" : "Podètz apondre des emmagazinatges externes dins los paramètres personals",
    "Name" : "Nom",
    "Storage type" : "Tipe d'emmagazinatge",
    "Scope" : "Portada",
    "External Storage" : "Emmagazinatge externe",
    "Folder name" : "Nom del dorsièr",
    "Authentication" : "Autentificacion",
    "Configuration" : "Configuracion",
    "Available for" : "Disponible per",
    "Advanced settings" : "Paramètres avançats",
    "Delete" : "Suprimir",
    "Add storage" : "Apondre un supòrt d'emmagazinatge",
    "Enable User External Storage" : "Autorizar los utilizaires a apondre d'emmagazinatges extèrnes",
    "Allow users to mount the following external storage" : "Autorizar los utilizaires a montar los emmagazinatges extèrnes seguents"
},
"nplurals=2; plural=(n > 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/files_external/l10n/oc.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "L'obtencion dels getons de requèsta a fracassat. Verificatz que vòstra clau d'aplicacion e vòstre senhal son corrèctes.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "L'obtencion dels getons d'aacès a fracassat. Verificatz que vòstra clau d'aplicacion e vòstre senhal son corrèctes.",
    "Please provide a valid app key and secret." : "Provesissètz una clau d'aplicacion e un senhal valids.",
    "Step 1 failed. Exception: %s" : "L’etapa 1 a fracassat. Error : %s",
    "Step 2 failed. Exception: %s" : "L’etapa 2 a fracassat. Error : %s",
    "External storage" : "Emmagazinatge extèrne",
    "Storage with id \"%i\" not found" : "Emmagazinatge amb l'id \"%i\" pas trobat",
    "Invalid backend or authentication mechanism class" : "Servici o metòde d'autentificacion pas valable",
    "Invalid mount point" : "Punt de montatge invalid",
    "Objectstore forbidden" : "\"Objectstore\" interdich",
    "Invalid storage backend \"%s\"" : "Servici d'emmagazinatge invalid : \"%s\"",
    "Not permitted to use backend \"%s\"" : "Pas autorizat a utilizar lo servici \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Pas autorizat a utilizar lo mecanisme d'autentificacion \"%s\"",
    "Unsatisfied backend parameters" : "Paramètres mancants pel servici",
    "Unsatisfied authentication mechanism parameters" : "Paramètres mancants pel metòde d'autentificacion",
    "Insufficient data: %s" : "Donadas insufisentas : %s",
    "Personal" : "Personal",
    "System" : "Sistèma",
    "Grant access" : "Autorizar l'accès",
    "Access granted" : "Accès autorizat",
    "Error configuring OAuth1" : "Error al moment de la configuracion d'OAuth1",
    "Error configuring OAuth2" : "Error al moment de la configuracion d'OAuth2",
    "Generate keys" : "Generar de claus",
    "Error generating key pair" : "Error al moment de la generacion de las claus",
    "Enable encryption" : "Activar lo chiframent",
    "Enable previews" : "Activar las previsualizacions",
    "Check for changes" : "Recercar las modificacions",
    "Never" : "Pas jamai",
    "Once every direct access" : "Un còp a cada accès dirècte",
    "All users. Type to select user or group." : "Totes los utilizaires. Clicatz aicí per restrénher.",
    "(group)" : "(grop)",
    "Saved" : "Enregistrat",
    "Username" : "Nom d'utilizaire",
    "Password" : "Senhal",
    "Save" : "Enregistrar",
    "Access key" : "Clau d'accès",
    "Secret key" : "Clau secreta",
    "Builtin" : "Integrat",
    "None" : "Pas cap",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "Clau API",
    "Username and password" : "Nom d'utilizaire e senhal",
    "RSA public key" : "Clau publica RSA",
    "Public key" : "Clau publica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l'òste",
    "Port" : "Pòrt",
    "Region" : "Region",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Accès per path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sosdorsièr distant",
    "Secure https://" : "Securizacion https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Òste",
    "Secure ftps://" : "Securizacion ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Emplaçament",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Raiç",
    "SFTP with secret key login" : "SFTP amb un identificant secret",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partejar",
    "Domain" : "Domeni",
    "SMB / CIFS using OC login" : "SMB / CIFS en utilizant los identificants OC",
    "Username as share" : "Nom d'utilizaire coma nom de partiment",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom del servici",
    "Request timeout (seconds)" : "Timeout de las requèstas (en segondas)",
    "<b>Note:</b> " : "<b>Atencion :</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion :</b> La presa en carga de cURL per PHP es pas activada o installada. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion : </b> La presa en carga del FTP per PHP es pas activada o installada. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion : </b> \"%s\" es pas installat. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "No external storage configured" : "Aucun emmagazinatge externe configurat",
    "You can add external storages in the personal settings" : "Podètz apondre des emmagazinatges externes dins los paramètres personals",
    "Name" : "Nom",
    "Storage type" : "Tipe d'emmagazinatge",
    "Scope" : "Portada",
    "External Storage" : "Emmagazinatge externe",
    "Folder name" : "Nom del dorsièr",
    "Authentication" : "Autentificacion",
    "Configuration" : "Configuracion",
    "Available for" : "Disponible per",
    "Add storage" : "Apondre un supòrt d'emmagazinatge",
    "Advanced settings" : "Paramètres avançats",
    "Delete" : "Suprimir",
    "Allow users to mount external storage" : "Autorizar los utilizaires a montar l'espaci d'emmagazinatge extèrne",
    "Allow users to mount the following external storage" : "Autorizar los utilizaires a montar los emmagazinatges extèrnes seguents"
},
"nplurals=2; plural=(n > 1);");
